=== modified file 'EXTERNALS'
--- EXTERNALS	2011-10-05 00:50:53 +0000
+++ EXTERNALS	2012-02-07 14:36:29 +0000
@@ -5,3 +5,5 @@
 - the time picker is provided by Maxime Haineault.  See http://haineault.com/media/jquery/ui-timepickr/page/ for more information about the JQuery UI Timepicker.
 
 - the map image and corresponding CSS is provided by from http://www.noobcube.com/tutorials/html-css/css-image-maps-a-beginners-guide-/ under the GNU Free Documentation License.
+
+- the markup template tags are from the Django 1.4 alpha

=== added file 'loco_directory/common/templatetags/markup.py'
--- loco_directory/common/templatetags/markup.py	1970-01-01 00:00:00 +0000
+++ loco_directory/common/templatetags/markup.py	2012-02-07 14:36:29 +0000
@@ -0,0 +1,89 @@
+"""
+Copied from Django 1.4 alpha
+
+Set of "markup" template filters for Django.  These filters transform plain text
+markup syntaxes to HTML; currently there is support for:
+
+    * Textile, which requires the PyTextile library available at
+      http://loopcore.com/python-textile/
+
+    * Markdown, which requires the Python-markdown library from
+      http://www.freewisdom.org/projects/python-markdown
+
+    * reStructuredText, which requires docutils from http://docutils.sf.net/
+"""
+
+from django import template
+from django.conf import settings
+from django.utils.encoding import smart_str, force_unicode
+from django.utils.safestring import mark_safe
+
+register = template.Library()
+
+@register.filter
+def textile(value):
+    try:
+        import textile
+    except ImportError:
+        if settings.DEBUG:
+            raise template.TemplateSyntaxError("Error in {% textile %} filter: The Python textile library isn't installed.")
+        return force_unicode(value)
+    else:
+        return mark_safe(force_unicode(textile.textile(smart_str(value), encoding='utf-8', output='utf-8')))
+
+@register.filter
+def markdown(value, arg=''):
+    """
+    Runs Markdown over a given value, optionally using various
+    extensions python-markdown supports.
+
+    Syntax::
+
+        {{ value|markdown:"extension1_name,extension2_name..." }}
+
+    To enable safe mode, which strips raw HTML and only returns HTML
+    generated by actual Markdown syntax, pass "safe" as the first
+    extension in the list.
+
+    If the version of Markdown in use does not support extensions,
+    they will be silently ignored.
+
+    """
+    try:
+        import markdown
+    except ImportError:
+        if settings.DEBUG:
+            raise template.TemplateSyntaxError("Error in {% markdown %} filter: The Python markdown library isn't installed.")
+        return force_unicode(value)
+    else:
+        # markdown.version was first added in 1.6b. The only version of markdown
+        # to fully support extensions before 1.6b was the shortlived 1.6a.
+        if hasattr(markdown, 'version'):
+            extensions = [e for e in arg.split(",") if e]
+            if len(extensions) > 0 and extensions[0] == "safe":
+                extensions = extensions[1:]
+                safe_mode = True
+            else:
+                safe_mode = False
+
+            # Unicode support only in markdown v1.7 or above. Version_info
+            # exist only in markdown v1.6.2rc-2 or above.
+            if getattr(markdown, "version_info", None) < (1,7):
+                return mark_safe(force_unicode(markdown.markdown(smart_str(value), extensions, safe_mode=safe_mode)))
+            else:
+                return mark_safe(markdown.markdown(force_unicode(value), extensions, safe_mode=safe_mode))
+        else:
+            return mark_safe(force_unicode(markdown.markdown(smart_str(value))))
+
+@register.filter
+def restructuredtext(value):
+    try:
+        from docutils.core import publish_parts
+    except ImportError:
+        if settings.DEBUG:
+            raise template.TemplateSyntaxError("Error in {% restructuredtext %} filter: The Python docutils library isn't installed.")
+        return force_unicode(value)
+    else:
+        docutils_settings = getattr(settings, "RESTRUCTUREDTEXT_FILTER_SETTINGS", {})
+        parts = publish_parts(source=smart_str(value), writer_name="html4css1", settings_overrides=docutils_settings)
+        return mark_safe(force_unicode(parts["fragment"]))

=== modified file 'loco_directory/templates/events/global_event_detail.inc.html'
--- loco_directory/templates/events/global_event_detail.inc.html	2012-02-06 15:06:39 +0000
+++ loco_directory/templates/events/global_event_detail.inc.html	2012-02-07 14:36:29 +0000
@@ -1,4 +1,4 @@
-{% load i18n teams_tags %}
+{% load i18n teams_tags markup %}
 {% block extrahead %}{{ block.super }}
 
 {% if global_event_object.pictag %}
@@ -74,7 +74,7 @@
     {% if global_event_object.description %}
         <table id="global-event-basic">
             <tr>
-                <td class="form-item-value">{{ global_event_object.description|linebreaksbr|urlize }}</td>
+                <td class="form-item-value">{{ global_event_object.description|markdown }}</td>
             </tr>
         </table>
     {% endif %}

=== modified file 'loco_directory/templates/events/team_event_detail.inc.html'
--- loco_directory/templates/events/team_event_detail.inc.html	2011-11-11 01:09:04 +0000
+++ loco_directory/templates/events/team_event_detail.inc.html	2012-02-07 14:36:29 +0000
@@ -1,10 +1,10 @@
-{% load i18n %}
+{% load i18n markup %}
 <article class="double-side-content">
     <h2>{{team_event_object.name}}</h2>
     {% if team_event_object.description %}
         <table id="team-event-basic">
             <tr>
-                <td class="form-item-value">{{ team_event_object.description|linebreaksbr|urlize }}</td>
+                <td class="form-item-value">{{ team_event_object.description|markdown:'safe' }}</td>
             </tr>
         </table>
     {% endif %}

=== modified file 'loco_directory/templates/meetings/team_meeting_detail_agenda.inc.html'
--- loco_directory/templates/meetings/team_meeting_detail_agenda.inc.html	2011-03-08 16:43:25 +0000
+++ loco_directory/templates/meetings/team_meeting_detail_agenda.inc.html	2012-02-07 14:36:29 +0000
@@ -1,4 +1,4 @@
-{% load i18n %}
+{% load i18n markup %}
 {% load recurse %}
 {% if user_is_team_member %}
     <p>
@@ -18,7 +18,7 @@
                 - <a class="agenda-sig" target="launchpaduser" href="https://launchpad.net/~{{ item.owner.user.username}}">{{ item.owner.realname }}</a>
                 @ {{ item.created_date|date:"D, d N Y H:i T" }}
             {% if item.description %}
-                <div class="agenda-description">{{ item.description|urlize|linebreaks }}</div>
+                <div class="agenda-description">{{ item.description|markdown:'safe' }}</div>
             {% endif %}
             </li>
             {% child %}

=== modified file 'loco_directory/templates/venues/venue_detail_basic.inc.html'
--- loco_directory/templates/venues/venue_detail_basic.inc.html	2011-08-22 23:39:28 +0000
+++ loco_directory/templates/venues/venue_detail_basic.inc.html	2012-02-07 14:36:29 +0000
@@ -1,4 +1,4 @@
-{% load i18n %}
+{% load i18n markup %}
 <table>
 {% if venue_object %}
     {% if venue_object.name %}
@@ -58,7 +58,7 @@
     {% if venue_object.comment %}
         <tr>
             <th class="form-item-label" scope="row">{% trans "Comment:" %}</th>
-            <td class="form-item-value">{{ venue_object.comment|linebreaksbr }}</td>
+            <td class="form-item-value">{{ venue_object.comment|markdown:'safe' }}</td>
         </tr>
     {% endif %}
 {% endif %}

=== modified file 'requirements.txt'
--- requirements.txt	2011-11-12 15:48:14 +0000
+++ requirements.txt	2012-02-07 14:36:29 +0000
@@ -27,3 +27,4 @@
 launchpadlib==1.6.0
 
 
+Markdown==2.1.1

